/***
 * Fractal ADL Parser
 * Copyright (C) 2002-2004 France Telecom R&D
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: Eric.Bruneton@rd.francetelecom.com
 *
 * Author: Eric Bruneton
 */

package org.objectweb.fractal.adl.arguments;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.StringTokenizer;

import org.objectweb.fractal.adl.ADLException;
import org.objectweb.fractal.adl.Definition;
import org.objectweb.fractal.adl.components.ComponentLoader;

public class ArgumentComponentLoader extends ComponentLoader {

  public Definition load (
    final List loaded,
    final String name,
    final Map context) throws ADLException 
  {
    String n = name;
    Map c = context;
    int i = name.indexOf('(');
    if (i != -1) {
      if (!name.endsWith(")")) {
        throw new ADLException("Syntax error in definition name", null);
      }
      
      n = name.substring(0, i);
      c = new HashMap();
      Iterator j = context.keySet().iterator();
      while (j.hasNext()) {
        String key = (String)j.next();
        if (!key.startsWith(" arg ")) {
          c.put(key, context.get(key));
        }
      }
      
      String args = name.substring(i + 1, name.length() - 1);
      StringTokenizer st = new StringTokenizer(args, ",");
      i = 0;
      while (st.hasMoreTokens()) {
        c.put(" arg " + (i++), st.nextToken()); 
      }
    }
    return super.load(loaded, n, c);
  }

  public List parseDefinitions (String nameList) {
    List l = new ArrayList();
    int c = nameList.lastIndexOf('(');
    int p = c == -1 ? nameList.lastIndexOf(',') : nameList.lastIndexOf(',', c);
    while (p != -1) {
      //l.add(0, nameList.substring(0, p));
      //nameList = nameList.substring(p+1);
      l.add(0, nameList.substring(p+1));
      nameList = nameList.substring(0, p);
      c = nameList.lastIndexOf('(');
      p = c == -1 ? nameList.lastIndexOf(',') : nameList.lastIndexOf(',', c);
    }
    l.add(0, nameList);
    return l;      
  }
  
  public boolean isShared (String definition) {
    return definition.indexOf('/') != -1 && definition.indexOf('(') == -1;
  }
}
