/**
 * Copyright (C) 2002 
 */

package org.objectweb.util.monolog.file.api;

/**
 * This interface decribes the special characters used to describe a pattern.
 * All special characters must be prefix by '%'. Here is an example of
 * pattern: <br/>
 * %l %t %m%n <br/>
 * This pattern will print on a single line the level, the topic name and the
 * message.
 *
 * @author Sebastien Chassande-Barrioz
 */
public interface Pattern {

	/**
	 * This character represents the level name of the message
	 */
	char LEVEL 			= 'l';

	/**
	 * This character represents the topic of the logger
	 */
	char TOPIC 			= 't';

	/**
	 * This character represents the date where the message has been logged
	 */
	char DATE 			= 'd';

	/**
	 * The theard name which has logged the message.
	 */
	char THREAD			= 'h';

	/**
	 * The message which has been logged
	 */
	char MESSAGE 		= 'm';

	/**
	 * This character represents the method in which the log method was called.
	 * Generating caller location information is extremly slow.
	 */
	char METHOD 		= 'M';

	/**
	 * This character represents the class name in which the log method was
	 * called. Generating caller location information is extremly slow.
	 */
	char OBJECT 		= 'O';

	/**
	 * This character represents the line number in the source code where the
	 * log method was called. Generating caller location information is
	 * extremly slow.
	 */
	char LINE_NUMBER	= 'L';

	/**
	 * This character is the prefix of all special character
	 */
	char PREFIX			= '%';

	/**
	 * This character represents a new line.
	 */
	char NEW_LINE		= 'n';


}
